@@ -7,6 +7,33 @@ class TestMTLRenderPipelineHelper(Metal.NSObject):
     def supportIndirectCommandBuffers(self):
         return 1
 
+    def textureWriteRoundingMode(self):
+        return 1
+
+    def maxTotalThreadsPerThreadgroup(self):
+        return 1
+
+    def threadgroupSizeMatchesTileSize(self):
+        return 1
+
+    def imageblockSampleLength(self):
+        return 1
+
+    def imageblockMemoryLengthForDimensions_(self, a):
+        return 1
+
+    def functionHandleWithFunction_stage_(self, a, b):
+        return 1
+
+    def newVisibleFunctionTableWithDescriptor_stage_(self, a, b):
+        return 1
+
+    def newIntersectionFunctionTableWithDescriptor_stage_(self, a, b):
+        return 1
+
+    def newRenderPipelineStateWithAdditionalBinaryFunctions_error_(self, a, b):
+        return 1
+
 
 class TestMTLRenderPipeline(TestCase):
     def test_constants(self):
@@ -75,6 +102,27 @@ class TestMTLRenderPipeline(TestCase):
             TestMTLRenderPipelineHelper.supportIndirectCommandBuffers
         )
 
+        self.assertArgHasType(
+            TestMTLRenderPipelineHelper.functionHandleWithFunction_stage_,
+            1,
+            objc._C_NSUInteger,
+        )
+        self.assertArgHasType(
+            TestMTLRenderPipelineHelper.newVisibleFunctionTableWithDescriptor_stage_,
+            1,
+            objc._C_NSUInteger,
+        )
+        self.assertArgHasType(
+            TestMTLRenderPipelineHelper.newIntersectionFunctionTableWithDescriptor_stage_,
+            1,
+            objc._C_NSUInteger,
+        )
+        self.assertArgHasType(
+            TestMTLRenderPipelineHelper.newRenderPipelineStateWithAdditionalBinaryFunctions_error_,
+            1,
+            b"o^@",
+        )
+
     @min_os_level("10.11")
     def test_methods10_11(self):
         self.assertResultIsBOOL(
@@ -119,6 +167,9 @@ class TestMTLRenderPipeline(TestCase):
             .setTessellationFactorScaleEnabled_,
             0,
         )
+
+    @min_os_level("10.14")
+    def test_methods10_14(self):
         self.assertResultIsBOOL(
             Metal.MTLRenderPipelineDescriptor.alloc()
             .init()
@@ -130,3 +181,41 @@ class TestMTLRenderPipeline(TestCase):
             .setSupportIndirectCommandBuffers_,
             0,
         )
+
+    @min_os_level("12.0")
+    def test_methods12_0(self):
+        self.assertResultIsBOOL(
+            Metal.MTLRenderPipelineDescriptor.alloc()
+            .init()
+            .supportAddingVertexBinaryFunctions
+        )
+        self.assertArgIsBOOL(
+            Metal.MTLRenderPipelineDescriptor.alloc()
+            .init()
+            .setSupportAddingVertexBinaryFunctions_,
+            0,
+        )
+
+        self.assertResultIsBOOL(
+            Metal.MTLRenderPipelineDescriptor.alloc()
+            .init()
+            .supportAddingFragmentBinaryFunctions
+        )
+        self.assertArgIsBOOL(
+            Metal.MTLRenderPipelineDescriptor.alloc()
+            .init()
+            .setSupportAddingFragmentBinaryFunctions_,
+            0,
+        )
+
+        self.assertResultIsBOOL(
+            Metal.MTLTileRenderPipelineDescriptor.alloc()
+            .init()
+            .supportAddingBinaryFunctions
+        )
+        self.assertArgIsBOOL(
+            Metal.MTLTileRenderPipelineDescriptor.alloc()
+            .init()
+            .setSupportAddingBinaryFunctions_,
+            0,
+        )
